@@ -3,9 +3,6 @@ _base_ = [
     '../../_base_/default_runtime.py'
 ]
 
-# model settings
-model = dict(cls_head=dict(dropout_ratio=0.5, init_std=0.001))
-
 # dataset settings
 dataset_type = 'RawframeDataset'
 data_root = 'data/kinetics400/rawframes_train'
@@ -16,7 +13,7 @@ ann_file_test = 'data/kinetics400/kinetics400_val_list_rawframes.txt'
 img_norm_cfg = dict(
     mean=[123.675, 116.28, 103.53], std=[58.395, 57.12, 57.375], to_bgr=False)
 train_pipeline = [
-    dict(type='DenseSampleFrames', clip_len=1, frame_interval=1, num_clips=5),
+    dict(type='DenseSampleFrames', clip_len=1, frame_interval=1, num_clips=8),
     dict(type='RawFrameDecode'),
     dict(type='Resize', scale=(-1, 256)),
     dict(
@@ -64,9 +61,8 @@ test_pipeline = [
     dict(type='ToTensor', keys=['imgs'])
 ]
 data = dict(
-    videos_per_gpu=16,
+    videos_per_gpu=12,
     workers_per_gpu=2,
-    val_dataloader=dict(videos_per_gpu=1),
     test_dataloader=dict(videos_per_gpu=1),
     train=dict(
         type=dataset_type,
@@ -84,13 +80,12 @@ data = dict(
         data_prefix=data_root_val,
         pipeline=test_pipeline))
 evaluation = dict(
-    interval=2, metrics=['top_k_accuracy', 'mean_class_accuracy'])
+    interval=5, metrics=['top_k_accuracy', 'mean_class_accuracy'])
 
 # optimizer
 optimizer = dict(
-    type='SGD', lr=0.03, momentum=0.9,
+    type='SGD', lr=0.005, momentum=0.9,
     weight_decay=0.0001)  # this lr is used for 8 gpus
-optimizer_config = dict(grad_clip=dict(max_norm=20, norm_type=2))
 
 # runtime settings
-work_dir = './work_dirs/tsn_r50_dense_1x1x5_100e_kinetics400_rgb/'
+work_dir = './work_dirs/tsn_r50_dense_1x1x8_100e_kinetics400_rgb/'
