@@ -214,7 +214,7 @@ class LoadKineticsPose:
             joint. Persons with low confidence scores are dropped (if exceed
             max_person). Default: dict(face=1, torso=2, limb=3).
         source (str): The sources of the keypoints used. Choices are 'mmpose'
-            and 'openpose'. Default: 'mmpose'.
+            and 'openpose-18'. Default: 'mmpose'.
         kwargs (dict, optional): Arguments for FileClient.
     """
 
@@ -232,7 +232,7 @@ class LoadKineticsPose:
         self.keypoint_weight = cp.deepcopy(keypoint_weight)
         self.source = source
 
-        if source == 'openpose':
+        if source == 'openpose-18':
             self.kpsubset = dict(
                 face=[0, 14, 15, 16, 17],
                 torso=[1, 2, 8, 5, 11],
@@ -280,8 +280,8 @@ class LoadKineticsPose:
 
         def mapinds(inds):
             uni = np.unique(inds)
-            mapp = {x: i for i, x in enumerate(uni)}
-            inds = [mapp[x] for x in inds]
+            map_ = {x: i for i, x in enumerate(uni)}
+            inds = [map_[x] for x in inds]
             return np.array(inds, dtype=np.int16)
 
         if self.squeeze:
@@ -292,7 +292,7 @@ class LoadKineticsPose:
         results['total_frames'] = total_frames
 
         h, w = results['img_shape']
-        if self.source == 'openpose':
+        if self.source == 'openpose-18':
             kps[:, :, 0] *= w
             kps[:, :, 1] *= h
 
@@ -629,3 +629,67 @@ class GeneratePoseTarget:
                     f'left_kp={self.left_kp}, '
                     f'right_kp={self.right_kp})')
         return repr_str
+
+
+@PIPELINES.register_module()
+class PaddingWithLoop:
+    """Sample frames from the video.
+
+    To sample an n-frame clip from the video, PaddingWithLoop samples
+    the frames from zero index, and loop the frames if the length of
+    video frames is less than te value of 'clip_len'.
+
+    Required keys are "total_frames", added or modified keys
+    are "frame_inds", "clip_len", "frame_interval" and "num_clips".
+
+    Args:
+        clip_len (int): Frames of each sampled output clip.
+        num_clips (int): Number of clips to be sampled. Default: 1.
+    """
+
+    def __init__(self, clip_len, num_clips=1):
+
+        self.clip_len = clip_len
+        self.num_clips = num_clips
+
+    def __call__(self, results):
+        num_frames = results['total_frames']
+
+        start = 0
+        inds = np.arange(start, start + self.clip_len)
+        inds = np.mod(inds, num_frames)
+
+        results['frame_inds'] = inds.astype(np.int)
+        results['clip_len'] = self.clip_len
+        results['frame_interval'] = None
+        results['num_clips'] = self.num_clips
+        return results
+
+
+@PIPELINES.register_module()
+class PoseNormalize:
+    """Normalize the range of keypoint values to [-1,1].
+
+    Args:
+        mean (list | tuple): The mean value of the keypoint values.
+        min_value (list | tuple): The minimum value of the keypoint values.
+        max_value (list | tuple): The maximum value of the keypoint values.
+    """
+
+    def __init__(self,
+                 mean=(960., 540., 0.5),
+                 min_value=(0., 0., 0.),
+                 max_value=(1920, 1080, 1.)):
+        self.mean = np.array(mean, dtype=np.float32).reshape(-1, 1, 1, 1)
+        self.min_value = np.array(
+            min_value, dtype=np.float32).reshape(-1, 1, 1, 1)
+        self.max_value = np.array(
+            max_value, dtype=np.float32).reshape(-1, 1, 1, 1)
+
+    def __call__(self, results):
+        keypoint = results['keypoint']
+        keypoint = (keypoint - self.mean) / (self.max_value - self.min_value)
+        results['keypoint'] = keypoint
+        results['keypoint_norm_cfg'] = dict(
+            mean=self.mean, min_value=self.min_value, max_value=self.max_value)
+        return results
